@@ -1,14 +1,7 @@
-library(plotly)
-
-Wpca.plot <- function(arclength, WfdList, Wdim=NULL, nharm=2, rotate=TRUE, 
-                       titlestr=NULL) {
+Wpca.plot <- function(WfdList, Wdim=NULL, 
+                      nharm=2, rotate=TRUE, titlestr=NULL) {
   
-  #  Last modified 13 July 2023 by Juan Li
-  
-  #  set up matrices of fine mesh values
-  
-  nfine   <- 101
-  indfine <- seq(0,arclength,len=nfine)
+  #  Last modified 27 September 2023 by Jim Ramsay
   
   #  set up the dimension of the over-space containing the test info curve
   
@@ -24,38 +17,36 @@ Wpca.plot <- function(arclength, WfdList, Wdim=NULL, nharm=2, rotate=TRUE,
   #  and the first derivative of the surprisal values for the total 
   #  of the curves
   
+  nfine   <- 101
+  indfine <- seq(0,100,len=nfine)
+  
   Pmat_full  <- matrix(0,nfine, Wdim)
   Wmat_full  <- matrix(0,nfine, Wdim)
   DWmat_full <- matrix(0,nfine, Wdim)
   
   n <- length(WfdList)
   m2 <- 0
-  for (i in 1:n) {
-    WListi <- WfdList[[i]]
+  for (item in 1:n) {
+    WListi <- WfdList[[item]]
     Wfdi   <- WListi$Wfd
     Mi     <- WListi$M
     m1 <- m2 +  1
     m2 <- m2 + Mi
-    Wmat_full[,m1:m2]  <- eval.surp(indfine,Wfdi)
-    DWmat_full[,m1:m2] <- eval.surp(indfine,Wfdi,1)
+    Wmat_full[,m1:m2]  <- eval.surp(indfine, Wfdi)
+    DWmat_full[,m1:m2] <- eval.surp(indfine, Wfdi,1)
     Pmat_full[,m1:m2]  <- Mi^(Wmat_full[,m1:m2])
   }
   
-  #  set up basis for (smoothing over arclength)
+  #  set up basis for (smoothing over [0,100])
   
   Wnbasis <- 7
   Wnorder <- 4
-  Wbasis  <- fda::create.bspline.basis(c(0,arclength), Wnbasis, Wnorder) 
+  Wbasis  <- fda::create.bspline.basis(c(0,100), Wnbasis, Wnorder) 
   WfdPar  <- fda::fdPar(fd(matrix(0,Wnbasis,1),Wbasis))
   
-   #  fine mesh of points along manifold of length arclength
-  
-  nfine <- dim(Wmat_full)[1]
-  arclengthfine <- seq(0,arclength,len=nfine)
-  
   #  smooth all Wdim surprisal curves to get best fitting fd curves
   
-  Sfd <- fda::smooth.basis(arclengthfine, Wmat_full, WfdPar)$fd
+  Sfd <- fda::smooth.basis(indfine, Wmat_full, WfdPar)$fd
   
   #  functional PCA of the fd versions of surprisal curves
   #  the output is nharm principal component functions
@@ -69,11 +60,6 @@ Wpca.plot <- function(arclength, WfdList, Wdim=NULL, nharm=2, rotate=TRUE,
   #  compute variance proportions for unrotated solution
   
   varprop  <- pcaList$varprop
-  eigvals  <- pcaList$values
-  rooteigs <- sqrt(eigvals)[1:nharm]
-  
-  #  carry out a varimax rotation if desired
-  
   if (!rotate) {
     varmxList    <- pcaList
     harmvarmxfd  <- harmfd
@@ -92,12 +78,13 @@ Wpca.plot <- function(arclength, WfdList, Wdim=NULL, nharm=2, rotate=TRUE,
   if (nharm == 2 || nharm == 3) {
     pind   <- c(5,25,50,75,95)
     Qlabel <- c("5%","25%","50%","75%","95%")
-    #  plot manifold along with marker and mesh points and crossing lines
-    harmmat  <- -fda::eval.fd(arclengthfine, harmvarmxfd)
-    Qvec_al  <-  arclengthfine[ceiling(nfine*c(0.05, 0.25, 0.50, 0.75, 0.95))]
-    Qvec_pts <- -fda::eval.fd(Qvec_al, harmvarmxfd)
+    harmmat    <- -fda::eval.fd(indfine, harmvarmxfd)
+    Qvec <- pind
+    Qvec_pts   <- -fda::eval.fd(Qvec, harmvarmxfd)
+    df_harmmat <- as.data.frame(harmmat)
+    df_Q       <- as.data.frame(Qvec_pts)
+    df_Q$label <- Qlabel
     if (nharm == 2) {
-      df_harmmat <- as.data.frame(harmmat)
       fig <- plot_ly(df_harmmat, x = ~PC1, y = ~PC2, type = 'scatter', 
                      mode = 'lines',
                      opacity = 1, 
@@ -105,29 +92,24 @@ Wpca.plot <- function(arclength, WfdList, Wdim=NULL, nharm=2, rotate=TRUE,
         layout(title = titlestr,
                showlegend = FALSE)
       
-      df_Q <- as.data.frame(Qvec_pts)
-      df_Q$label <- Qlabel
       for (i in 1:5) {
         fig <- fig %>% 
           add_trace(x = df_Q$PC1[i], y = df_Q$PC2[i], 
-                    type = "scatter", text = df_Q$label[i], mode = "text")
+                    type = "scatter", text = df_Q$label[i], mode = "text+lines")
       }
       
     } else {
-      df_harmmat <- as.data.frame(harmmat)
       fig <- plot_ly(df_harmmat, x = ~PC1, y = ~PC2, z = ~PC3, type = 'scatter3d', 
                      mode = 'lines',
                      opacity = 1, 
-                     line = list(width = 6, color = "black", reverscale = FALSE))%>% 
+                     line = list(width = 6, color = "black", reverscale = FALSE) ) %>% 
         layout(title = titlestr,
                showlegend = FALSE)
       
-      df_Q <- as.data.frame(Qvec_pts)
-      df_Q$label <- Qlabel
       for (i in 1:5) {
         fig <- fig %>% 
-          add_trace(x = df_Q$PC1[i], y = df_Q$PC2[i], z = df_Q$PC3[i], 
-                    type = "scatter3d", text = df_Q$label[i], mode = "text")
+          add_trace(x = df_Q$PC1[i], y = df_Q$PC2[i], z = df_Q$PC3[i], text = df_Q$label[i], 
+                    type = "scatter3d", mode = "text+lines")
       }
     }
   } else {
@@ -135,6 +117,6 @@ Wpca.plot <- function(arclength, WfdList, Wdim=NULL, nharm=2, rotate=TRUE,
   }
   
   return(list(pcaplt=fig, harmvarmxfd=harmvarmxfd, varpropvarmx=varpropvarmx,
-              harmmat=harmmat, Qvec_pts=Qvec_pts, Qvec_al=Qvec_al))
+              harmmat=harmmat, Qvec_pts=Qvec_pts, Qvec=Qvec))
   
 }
\ No newline at end of file
